module Flashee
  module Generators
    module Install
      # Houses the logic to install flashee into the target rails app using the bulma CSS framework.
      # BulmaGenerator translates to the `flashee:install:bulma` command.
      class BulmaGenerator < Rails::Generators::Base

        # Creates bulma mode helper.
        def create_helper
          @helper_file = Builders.helper_builder "bulma"
          helper_target_path = File.join(Rails.root, "app", "helpers", "flashee_helper.rb")

          Builders.file_builder helper_target_path, @helper_file
        end

        # Creates bulma mode view partial
        def create_partial
          Builders.view_builder "bulma"
        end

        # After installation completes, print the ERB snippet to the command line.
        def print_post_install_info
          puts "==================================================================="
          puts "# One more step to go, To render the                              #"
          puts "# flash messages, you will need to add                            #"
          puts "# this line to application.html.erb.                              #"
          puts "#                                                                 #"
          puts '# <%= render partial: "partials/flash_messages", flash: flash %>  #'
          puts "==================================================================="
        end
      end
    end
  end
end
